#
# spec file for package dc3dd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dc3dd
Version:        7.3.1
Release:        2.4
Summary:        Patched dd with Computer Forensics Features
License:        GPL-3.0-only
Group:          Productivity/Archiving/Backup
URL:            https://sourceforge.net/projects/dc3dd/
Source0:        https://sourceforge.net/projects/dc3dd/files/dc3dd/%{version}/%{name}-%{version}.zip
# PATCH-FIX-UPSTREAMING -- bmwiedemann -- https://sourceforge.net/p/dc3dd/bugs/16/
Patch0:         reproducible.patch
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  make
BuildRequires:  unzip
BuildRequires:  perl(Locale::gettext)

%description
dc3dd is a patched version of GNU dd to include a number of features useful
for computer forensics. Many of these features were inspired by dcfldd, but
were rewritten for dc3dd.

* Pattern writes. The program can write a single hexadecimal value or a text
  string to the output device for wiping purposes.
* Piecewise and overall hashing with multiple algorithms and variable size
  windows. Supports MD5, SHA-1, SHA-256, and SHA-512. Hashes can be computed
  before or after conversions are made.
* Progress meter with automatic input/output file size probing
* Combined log for hashes and errors
* Error grouping. Produces one error message for identical sequential errors
* Verify mode. Able to repeat any transformations done to the input file and
  compare it to an output.
* Ability to split the output into chunks with numerical or alphabetic
  extensions

%lang_package

%prep
%autosetup -p1

# fix end-of-line encoding
sed -i 's/\r$//' *.txt
sed -i 's/\r$//' ChangeLog
# Add executable flag to configure
chmod +x configure

%build
# hpa and dco detection is recommended for linux builds
%configure --enable-hpadco \
  gl_cv_func_printf_directive_n=yes \
  gl_cv_func_printf_infinite_long_double=yes
%make_build

%install
%make_install
%find_lang dc3dd

%files
%license COPYING
%doc ChangeLog NEWS THANKS
%doc *.txt
%{_bindir}/dc3dd
%{_mandir}/man1/dc3dd.1%{?ext_man}

%files lang -f %{name}.lang
%dir /usr/share/locale/*/LC_TIME

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu Jun 15 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- update to version 7.3.1:
  * use .zip source file
  * added BuildRequires: unzip
  * removed BuildRequires for p7zip(-full)
  * removed patch dc3dd-7.2.646-fix-FTBFS-with-glibc-2.28.patch as
    changes has been merged in the source
* Sat May 15 2021 Dirk Müller <dmueller@suse.com>
- stop owning directories provided by filesystem rpm (bsc#1184786)
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- BuildRequires p7zip for Leap <= 15.1 only
* Tue Dec 22 2020 Max Lin <mlin@suse.com>
- BuildRequires p7zip for Leap <= 15.2 only
* Mon Feb 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- add /usr/share/local to the lang package.
- a change internal to factory triggered this folder tree being created
* Fri Aug  9 2019 antoine.belvire@opensuse.org
- Update to version 7.2.646:
  * No code change, only bump version.
- Use .7z tarball:
  * The only alternative tarball provided by upstream for this
    version is a zip but its decompression returns exit code 1.
  * Pull p7zip(-full) as build dependency.
- Add dc3dd-7.2.646-fix-FTBFS-with-glibc-2.28.patch: Fix build.
- Clean spec file with spec-cleaner.
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Sun Jan  4 2015 Greg.Freemyer@gmail.com
- update Source: field to be the full URL and delete http: comment
- remove BuildRequires for libtool, automake, autoconf - they were not used
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 7.2.0
  + Log output may be sent to multiple job logs and hash logs. Simply specify
  log=LOG and/or hlog=LOG more than once.
  + Verification of an image restored to a device larger than the image is now
  supported. Specify hof=DEVICE to hash only the bytes dc3dd writes to the
  device. Specify fhod=DEVICE to hash both the bytes dc3dd writes to the
  device and all the bytes that follow, up to the end of the device.
  + Specifying hof=DEVICE will now default to phod=DEVICE behavior (hash only
  the bytes output by dc3dd, not the full device).
- Add xz make dependency; use xz tarball instead of bzipped one
- New dependency on perl(Locale::gettext)
- Strip out translations in lang_subpackage
- Remove depreciated Authors section
- Remove spurious executable bits of documentation files
* Tue Jul  9 2013 schwab@suse.de
- Override broken configure checks
* Thu Feb  9 2012 Greg.Freemyer@gmail.com
- add copyright notice to specfile
* Mon Oct 17 2011 Greg.Freemyer@gmail.com
- Update to 7.1.0
  2011-03-02 Richard Cordovano <rcordovano@users.sourceforge.net>
  * Added the ability to specify log= and hlog= more than once.
  * Added phod= and fhod= options. For an output that is a device, using phod= ("partially hashed output device")
    causes dc3dd to compute hashes of only the bytes dc3dd wrote to the output device. If fhod=
    ("fully hashed output device") is specified instead, dc3dd will compute hashes of both the bytes dc3dd wrote
    and of the entire device.
* Wed Mar 17 2010 pascal.bleser@opensuse.org
- update to 6.12.4-r458
  2009-08-28 Richard Cordovano <rcordovano@users.sourceforge.net>
  * Replaced the byte-by-byte verification capability with a verification capability that
    hashes imaging outputs and compares the hashes to the input hash. The new verification capability
    does not require a second read of the device.
  * Enhanced the ability to generate multiple outputs by adding the capability to combine split and unsplit
    outputs.
  * Added the ability for the user to specify a sector size via the command line.
  * Added display/logging of results of device size probes. Size probes are now always performed, providing
    run statistics in most use cases (reading from standard input excepted).
  * Added display/logging of size statistics for each file in an input or output split.
  * Simplified the command line options and removed all legacy dd features not needed for imaging. The simplified
    command line is more rigorously validated to reduce the likelihood of performing a run contrary to user
    intent in order to avoid a second read of a device.
  * Removed the progress=on command line option and the cumbersome INFO signaling protocol for
    obtaining a progress report. Instead, a progress bar is always displayed.
  * Added new DEFAULT_IMAGING_MODE compile flag support (equivalent to command line options:
    recovererrs=on, grouperrs=on, idirect=on).
  * Reduced the use of global variables from 71 to 9, reduced function lengths, and
    removed several instances of code duplication.
  * Introduced a program architecture that replaces a single loop with a jobs abstraction, allowing execution
    of an arbitrary chain of jobs, each composed of one or more tasks that execute in parallel. The new
    program architecture is designed to allow for the transparent addition of multi-step processing
    scenarios such as the new verification capability.
* Wed Oct  8 2008 guru@unixtech.be
- new package
